@@ -335,7 +335,7 @@ void KDirWatchPrivate::inotifyEventReceived()
                 m_inotify_wd_to_entry.remove(e->wd);
                 e->wd = -1;
                 e->m_ctime = invalid_ctime;
-                emitEvent(e, Deleted, e->path);
+                emitEvent(e, Deleted);
                 // If the parent dir was already watched, tell it something changed
                 Entry *parentEntry = entry(e->parentDirectory());
                 if (parentEntry) {
@@ -1562,7 +1562,8 @@ bool KDirWatchPrivate::isNoisyFile(const char *filename)
             return true;
         }
         // fontconfig updates the cache on every KDE app start
-        // (inclusive kio_thumbnail slaves)
+        // as well as during kio_thumbnail worker execution
+        // TODO:; check which fontconfig version this file was deprecated and the check can be removed
         if (strncmp(filename, ".fonts.cache", 12) == 0) {
             return true;
         }
